@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,7 +25,7 @@
 #include <QTreeWidget>
 #include <QHBoxLayout>
 #include <QHeaderView>
-
+#include <KAboutData>
 #include <QLocale>
 #include <QIcon>
 #include <QMenu>
@@ -68,7 +68,7 @@ FollowUpReminderInfoWidget::FollowUpReminderInfoWidget(QWidget *parent)
 {
     setObjectName(QStringLiteral("FollowUpReminderInfoWidget"));
     QHBoxLayout *hbox = new QHBoxLayout(this);
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     mTreeWidget = new QTreeWidget(this);
     mTreeWidget->setObjectName(QStringLiteral("treewidget"));
     QStringList headers;
@@ -143,10 +143,10 @@ void FollowUpReminderInfoWidget::createOrUpdateItem(FollowUpReminder::FollowUpRe
     item->setText(AnswerWasReceived, answerWasReceived ? i18n("Received") : i18n("On hold"));
     item->setData(0, AnswerItemFound, answerWasReceived);
     if (answerWasReceived) {
-        item->setBackgroundColor(DeadLine, Qt::green);
+        item->setBackground(DeadLine, Qt::green);
     } else {
         if (info->followUpReminderDate() < QDate::currentDate()) {
-            item->setBackgroundColor(DeadLine, Qt::red);
+            item->setBackground(DeadLine, Qt::red);
         }
     }
 #ifdef DEBUG_MESSAGE_ID
@@ -155,7 +155,7 @@ void FollowUpReminderInfoWidget::createOrUpdateItem(FollowUpReminder::FollowUpRe
 #endif
 }
 
-bool FollowUpReminderInfoWidget::save()
+bool FollowUpReminderInfoWidget::save() const
 {
     if (!mChanged) {
         return false;
